# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['obplatform']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.26.0,<3.0.0', 'tqdm>=4.62.3,<5.0.0']

extras_require = \
{'pandas': ['pandas>=1.3.4,<2.0.0']}

setup_kwargs = {
    'name': 'obplatform',
    'version': '1.0.0',
    'description': 'APIs to access ASHRAE OB Database',
    'long_description': '# OBPlatform\n\nA package to interact and download behavior data from [ASHRAE Global Occupant Behavior Database](https://ashraeobdatabase.com). Currently available on PyPI and conda-forge. More features coming in the furture.\n\n[![pypi](https://img.shields.io/pypi/v/obplatform.svg)](https://pypi.python.org/pypi/obplatform) [![conda-forge](https://img.shields.io/conda/vn/conda-forge/obplatform)](https://github.com/conda-forge/obplatform-feedstock#installing-obplatform) [![CI](https://github.com/umonaca/obplatform/actions/workflows/test.yml/badge.svg?event=push)](https://github.com/umonaca/obplatform/actions?query=event%3Apush+branch%3Amaster) [![codecov](https://codecov.io/gh/umonaca/obplatform/branch/master/graph/badge.svg?token=SCFFFX2IKX)](https://codecov.io/gh/umonaca/obplatform) ![license](https://img.shields.io/github/license/umonaca/obplatform) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/obplatform) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![Read the Docs](https://img.shields.io/readthedocs/obplatform)](https://obplatform.readthedocs.io/en/latest/index.html)\n\n## Features\n\n- List all behavior types available in the database.\n- Download data archive (ZIP file) based on behavior type and study id inputs (with progress bar).\n- Query studies based on (behaviors, countries, cities, (building type + room type)) (WIP).\n- Query available behavior types based on study ids (WIP)\n\n## Installation\n\n### poetry\n\n```\npoetry install\n```\n\n### pip\n\n```\npip install --upgrade obplatform\n```\n\n### conda\n\n```\nconda install -c conda-forge obplatform\n```\n\n**For Python 3.10**: If you see an error like the following when resolving dependencies, it\'s caused by [a bug](https://github.com/conda/conda/issues/10969) in conda with Python 3.10.\n\n```\nCollecting package metadata (current_repodata.json): done\nSolving environment: failed with initial frozen solve. Retrying with flexible solve.\nCollecting package metadata (repodata.json): done\nSolving environment: failed with initial frozen solve. Retrying with flexible solve.\n\nPackagesNotFoundError: The following packages are not available from current channels:\n\n  - python=3.1\n```\n\nThree possible solutions:\n\n1. Create a new conda environment with Python <3.10.\n2. Upgrade conda to a new version. (conda released 4.11.0 on 11/22/2021 at GitHub, which fixed the bug for Python 3.10. However, it will still take some time before conda 4.11.0 is available on Anaconda Cloud).\n3. Use [mamba](https://github.com/mamba-org/mamba), which is a reimplementation of the conda package manager in C++. It is much faster and contains less bugs.\n\n### mamba\n\nOnce you activate the environment through conda or micromamba:\n\n```\nmamba install -c conda-forge obplatform\n```\n\n## Example\n\n```python\nimport logging\nimport zipfile\n\nimport pandas as pd\nfrom obplatform import Connector, logger\n\nconnector = Connector()\n\n# List all behaviors available in the database\nprint(connector.list_behaviors())\n\n# Print progress information\n# Comment out the following line to hide progress information\nlogger.setLevel(logging.INFO)\n\n# Download Appliance Usage + Occupant Presence behaviors from study 22, 11, and 2.\nconnector.download_export(\n    "data.zip",\n    ["Appliance_Usage", "Occupancy_Measurement"],\n    ["22", "11", "2"],\n    show_progress_bar=True,  # False to disable progrees bar\n)\n\nbehavior_type = "Appliance_Usage"\nstudy_id = "22"\n\nzf = zipfile.ZipFile("data.zip")\ndf = pd.read_csv(zf.open(f"{behavior_type}_Study{study_id}.csv"))\nprint(df.head())\n\n# List all behaviors available in study 1, 2, 3, and 4\njson_study_behaviors = connector.list_behaviors_in_studies(studies=["1", "2", "3", "4"])\nprint(json_study_behaviors)\n```\n\n## Usage\n\n### Available behavior types\n\nPlease only use the following names as input. e.g. Please use `Lighting_Status` (listed below) instead of  `Lighting Adjustment`(displayed on the website).\n\n```\n\'Appliance_Usage\', \'Fan_Status\', \'Door_Status\', \'HVAC_Measurement\', \'Lighting_Status\', \'Occupant_Number\', \'Occupancy_Measurement\', \'Other_HeatWave\', \'Other_Role of habits in consumption\', \'Other_IAQ in Affordable Housing\', \'Shading_Status\', \'Window_Status\'\n```\n\nIn the next version, the package will auto detect either type of input and convert to the correct query parameter.\n\n### Note: big data\n\nStudy 2 is a special case. It has very large source files (> 2 GB) so we compressed all data in study 2 as a single `.tar.gz`file. In the example above, `data.zip` contains a `tar.gz`file along with several separate csv files from other studies. When writing libraries to read from csv file from the downloaded zip, Study 2 should be treated as a special case.\n\n## Changelog\n\n- 2021-11-18:  Release 0.1.3\n- 2021-11-19:  Release 0.1.4, fixed a minor issue with Python 3.10.0\n- 2021-11-23:  Release 1.0.0\n  - Breaking changes:\n    - Behavior type (query field) "Occupancy" has been renamed to "Occupancy_Measurement" to keep the name consistent. The example above has been changed accordingly. The server will reject query field "Occupancy".\n  - Added endpoint to check backend server health\n  - Added endpoint to query available behavior types based on Study IDs\n\n\n## TODO\n\n- Add function to query available studies based on (behaviors, countries, cities, (building type + room type))\n\n## API Reference\n\nhttps://obplatform.readthedocs.io/en/latest/index.html\n',
    'author': 'Wei Mu',
    'author_email': 'wmu100@syr.edu',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7.1,<4.0',
}


setup(**setup_kwargs)
